about summary refs log tree commit diff
path: root/home/fish/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'home/fish/default.nix')
-rw-r--r--home/fish/default.nix9
1 files changed, 6 insertions, 3 deletions
diff --git a/home/fish/default.nix b/home/fish/default.nix
index 5556ed2..85ff30d 100644
--- a/home/fish/default.nix
+++ b/home/fish/default.nix
@@ -11,10 +11,13 @@ in {
     interactiveShellInit = ''
       set fish_greeting
 
       # Tmux on terminal start
       if status is-interactive
-      and not set -q TMUX
-          exec tmux
+        if test -z "$SSH_CONNECTION"
+          if not tmux has-session 2>/dev/null; or test -z "$TMUX"
+            exec tmux new-session -A -s 0
+          end
+        end
       end
     '';
     loginShellInit = lib.mkIf swayEnabled ''
@@ -11,10 +11,13 @@ in {
       set fish_greeting
 
-      # Tmux on terminal start
+      # Tmux on terminal start, unless we're in a SSH connection
       if status is-interactive